library ieee;
use ieee.std_logic_1164.all;

entity piii is
	port(
		-- parallel port data and status pins
		ppd:				in	std_logic_vector(6 downto 0);
		pps:				out	std_logic_vector(5 downto 3);

		-- programmable oscillator
		clk: in std_logic;
		
		-- Spartan2 FPGA pins
		S2_tck:			out	std_logic;	-- driver to Spartan2 JTAG clock
		S2_tms:			out	std_logic;	-- driver to Spartan2 JTAG mode input
		S2_tdi:			out	std_logic;	-- driver to Spartan2 JTAG serial data input
		S2_tdo:			in	std_logic;	-- input from Spartan2 JTAG serial data output
		S2_cclk:		out	std_logic;	-- driver to Spartan2 config clock
		S2_prog_n:	out	std_logic;	-- driver to Spartan2 /PROGRAM pin
		S2_done:		in	std_logic;	-- input from Spartan2 DONE pin
		S2_din:			out	std_logic;	-- driver to Spartan2 config serial data input
		S2_m:				out	std_logic_vector(0 downto 0);	-- Spartan2 config mode pins
		S2_clk:			out std_logic;	-- clock output to Spartan2
		
		fce_n:			out	std_logic		-- Flash chip-enable
	);
end piii;

architecture arch of piii is
	constant NO:	std_logic := '0';
	constant YES:	std_logic := '1';
	constant LO:	std_logic := '0';
	constant HI:	std_logic := '1';
	constant SLAVE_SERIAL_MODE: std_logic_vector(0 downto 0) := "1";
	component pullup port(O: out std_logic); end component;
begin

	-- disable Flash chip when Spartan2 is not configured
	fce_n			<= HI when S2_done=NO else 'Z';
	
	-- send the programmable oscillator clock to the Spartan2
	S2_clk 		<= clk;
	
	-- the XSA power status is sent back through the parallel port status pin 3
	pps(3)		<= HI;		-- tell the PC that the VCC for the XSA board is OK
	-- the cable is detected by sending data through data pin 6 and returning
	-- it on status pins 5 and 7.  Status pin 7 is used by the JTAG TDO
	-- pin of the XC9500 CPLD on the XSA Board, so place a shunt at position "xi"
	-- of jumper J9 to make this connection.
	pps(5)		<= ppd(6);

	S2_m			<= SLAVE_SERIAL_MODE;	-- set Spartan2 config mode pins
	u0: pullup port map(O=>S2_prog_n);	-- place a pullup on the Spartan2 PROGRAM pin

	-- drive the Spartan2 JTAG pins from the parallel port when tristate
	-- control pin (parallel port data pin 3) is low.
	S2_tms		<= ppd(2) when ppd(3)=LO else 'Z';
	S2_tck		<= ppd(1) when ppd(3)=LO else 'Z';
	S2_tdi		<= ppd(0) when ppd(3)=LO else 'Z';

	-- the JTAG TDO output is sent back through the status pin
	pps(4)		<= S2_tdo when ppd(4)=HI else LO;

end arch;

